LinkedProject class final

The database of the project linked with supabase link, or of projectRef, reached through the Management API with the credentials of supabase login.

Inheritance

Constructors

LinkedProject({String? projectRef})
Creates the linked project target, optionally overriding the linked project with projectRef.
const

Properties

arguments List<String>
The supabase db query flags selecting this target.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
projectRef String?
The project ref to query instead of the linked one.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited