LocalDatabase class final

The database of the local Supabase stack started with supabase start.

Inheritance

Constructors

LocalDatabase()
Creates the local stack target.
const

Properties

arguments List<String>
The supabase db query flags selecting this target.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited