SupabaseCliException class
Thrown when supabase db query cannot run or fails, with a message
that tells the user what to do.
- Implemented types
Constructors
- SupabaseCliException(String message)
-
Creates the exception carrying
message.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited