SupabaseCliException class

Thrown when supabase db query cannot run or fails, with a message that tells the user what to do.

Implemented types

Constructors

SupabaseCliException(String message)
Creates the exception carrying message.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
What went wrong and how to fix it.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited